
#ifndef _SVETALIB_H
#define _SVETALIB_H

// ===== ERROR CODES =====

#define ERROR_NONE							0
#define ERROR_DEVICE_INDEX_OUT_OF_RANGE		1
#define ERROR_DEVICE_ALREADY_IN_USE			2
#define ERROR_DEVICE_OPEN_FAILURE			3
#define ERROR_INITIALISING                  4
#define ERROR_NOT_INITIALISED               5
#define ERROR_DEVICE_BUSY_OR_NOT_FOUND      6
#define ERROR_RETRIEVING_DEVICE_SIGNATURE   7
#define ERROR_DEVICE_SIGNATURE              8
#define ERROR_UNSUPPORTED_FIRMWARE_VERSION  9
#define ERROR_UNSUPPORTED_FEATURE           10
#define ERROR_READING_CALIBRATION           11
#define ERROR_READING_POLARITY              12
#define ERROR_PWM_CHANNEL_OUT_OF_RANGE      13
#define ERROR_PWM_DUTY_CYCLE_OUT_OF_RANGE   14
#define ERROR_SETTING_PWM_DUTY_CYCLE        15
#define ERROR_PWM_FREQUENCY_OUT_OF_RANGE    16
#define ERROR_SETTING_PWM_FREQUENCY         17
#define ERROR_OUTPUT_CHANNEL_OUT_OF_RANGE   18
#define ERROR_VOLTAGE_OUT_OF_RANGE          19
#define ERROR_CURRENT_OUT_OF_RANGE          20
#define ERROR_SETTING_VOLTAGE               21
#define ERROR_INVALID_POLARITY              22
#define ERROR_SETTING_POLARITY              23
#define ERROR_TURNING_VOLTAGE_ON            24
#define ERROR_TURNING_VOLTAGE_OFF           25
#define ERROR_INVALID_VOLTAGE_RANGE         26
#define ERROR_ENABLING_INTERNAL_BUS         27
#define ERROR_DISABLING_INTERNAL_BUS        28
#define ERROR_INTERNAL_BUS_DISABLED         29
#define ERROR_LP_USB_ONLY                   30
#define ERROR_GETTING_STATUS                31
#define ERROR_GETTING_CURRENT               32
#define ERROR_CLEARING_ERROR                33
#define ERROR_PWM_FUNCTION_UNKNOWN          34
#define ERROR_AMPLITUDE_OUT_OF_RANGE        35
#define ERROR_FREQUENCY_OUT_OF_RANGE        36
#define ERROR_UNKNOWN_WAVEFORM              37

// ===== POLARITY SETTINGS =====
#define POLARITY_POSITIVE                   0
#define POLARITY_NEGATIVE                   1
        
// ===== VOLTAGE BUS SETTINGS =====
#define RANGE_75V                           0
#define RANGE_100V                          1

// ===== ADVANCED PWM SETTINGS =====
#define PWM_FUNCTION_WAVEFORM_START_OUT1    0
#define PWM_FUNCTION_WAVEFORM_START_OUT2    1
#define PWM_FUNCTION_WAVEFORM_START_OUT3    2

// ===== WAVEFORM SETTINGS =====
#define WAVEFORM_TRIANGLE                   0
#define WAVEFORM_SAWTOOTH                   1
#define WAVEFORM_SINUSOIDAL                 2

// ===== API =====

extern "C" __declspec(dllexport) int __cdecl initialiseSession();
extern "C" __declspec(dllexport) int __cdecl closeSession();

extern "C" __declspec(dllexport) int __cdecl getDeviceCount(int* pCount);
extern "C" __declspec(dllexport) int __cdecl getDeviceIndex(const char* serialNumber, int *deviceIndex);

extern "C" __declspec(dllexport) int __cdecl setPWMFunction(int deviceIndex, int channel, int pwmFunction);
extern "C" __declspec(dllexport) int __cdecl setPWM(int deviceIndex, int channel, int dutyCycle);
extern "C" __declspec(dllexport) int __cdecl setPWMFrequency(int deviceIndex, int Hz);

extern "C" __declspec(dllexport) int __cdecl setVoltage(int deviceIndex, int channel, double voltage_V, double currentLimit_uA);
extern "C" __declspec(dllexport) int __cdecl setAccurateVoltage(int deviceIndex, int channel, double coarseVoltage_mV, double fineVoltage_uV);
extern "C" __declspec(dllexport) int __cdecl setVoltageWaveform(int deviceIndex, int channel, int waveformType, double offset_V, double amplitude_V, double frequency_Hz);
extern "C" __declspec(dllexport) int __cdecl setPolarity(int deviceIndex, int channel, int polarity);
extern "C" __declspec(dllexport) int __cdecl turnVoltageOn(int deviceIndex, int channel);
extern "C" __declspec(dllexport) int __cdecl turnVoltageOff(int deviceIndex, int channel);

extern "C" __declspec(dllexport) int __cdecl enableInternalVoltageBus(int deviceIndex, int range);
extern "C" __declspec(dllexport) int __cdecl disableInternalVoltageBus(int deviceIndex);

extern "C" __declspec(dllexport) int __cdecl getSupplyStatus(int deviceIndex, bool* hasError, char* errorDescription); 
extern "C" __declspec(dllexport) int __cdecl getChannelStatus(int deviceIndex, int channel, bool* isOn, bool* isCurrentLimit);
extern "C" __declspec(dllexport) int __cdecl getChannelCurrent(int deviceIndex, int channel, double* current_uA);
extern "C" __declspec(dllexport) int __cdecl clearError(int deviceIndex);

extern "C" __declspec(dllexport) int __cdecl getADCValue(int deviceIndex, double* voltage_mV);

#endif // _SVETALIB_H